@@ -8,8 +8,9 @@ from __future__ import annotations
 from typing import Any, Dict
 
 from ..const import GitHubRequestKwarg
+from ..models.repository import GitHubRepositoryModel
 from ..models.response import GitHubResponseModel
-from ..models.user import GitHubAuthenticatedUserModel, GitHubUserModel
+from ..models.user import GitHubUserModel
 from .base import BaseNamespace
 
 
@@ -18,28 +19,50 @@ class GitHubUsersNamespace(BaseNamespace):
 
     async def get(
         self,
-        username: str | None = None,
+        username: str,
         **kwargs: Dict[GitHubRequestKwarg, Any],
-    ) -> GitHubResponseModel[GitHubAuthenticatedUserModel | GitHubUserModel]:
+    ) -> GitHubResponseModel[GitHubUserModel]:
         """
          Get a user
 
          **Arguments**:
 
-         `username` (Optional)
+         `username`
 
-         The username to return, example "octocat", if not provided,
-         the authenticated user is returned
+         The username to return, example "octocat"
 
         https://docs.github.com/en/rest/reference/users#get-a-user
         """
         response = await self._client.async_call_api(
-            endpoint="/user" if not username else f"/users/{username}",
+            endpoint=f"/users/{username}",
             **kwargs,
         )
-        if username:
-            response.data = GitHubUserModel(response.data)
-        else:
-            response.data = GitHubAuthenticatedUserModel(response.data)
+        response.data = GitHubUserModel(response.data)
+
+        return response
+
+    async def starred(
+        self,
+        username: str,
+        **kwargs: Dict[GitHubRequestKwarg, Any],
+    ) -> GitHubResponseModel[list[GitHubRepositoryModel]]:
+        """
+         Get the starred repositories of a user
+
+         **Arguments**:
+
+         `username`
+
+         The username to return, example "octocat"
+
+
+        https://docs.github.com/en/rest/reference/users#get-a-user
+        """
+        response = await self._client.async_call_api(
+            endpoint=f"/users/{username}/starred",
+            **kwargs,
+        )
+
+        response.data = [GitHubRepositoryModel(data) for data in response.data]
 
         return response
